@@ -20,12 +20,17 @@
 #'   Performance measures for all tasks.
 #'   If missing, the default measure of the first task is used.
 #' @template arg_keep_pred
+#' @template arg_keep_extract
 #' @template arg_models
 #' @template arg_showinfo
 #' @return [BenchmarkResult].
 #' @family benchmark
 #' @export
 #' @examples
+#' \dontshow{ if (requireNamespace("rpart")) \{ }
+#' \dontshow{ if (requireNamespace("MASS")) \{ }
+#' \dontshow{ if (requireNamespace("rpart")) \{ }
+#' \dontshow{ if (requireNamespace("PMCMRplus")) \{ }
 #' lrns = list(makeLearner("classif.lda"), makeLearner("classif.rpart"))
 #' tasks = list(iris.task, sonar.task)
 #' rdesc = makeResampleDesc("CV", iters = 2L)
@@ -38,7 +43,13 @@
 #' plotBMRRanksAsBarChart(bmr, pos = "stack")
 #' friedmanTestBMR(bmr)
 #' friedmanPostHocTestBMR(bmr, p.value = 0.05)
-benchmark = function(learners, tasks, resamplings, measures, keep.pred = TRUE, models = TRUE, show.info = getMlrOption("show.info")) {
+#' \dontshow{ \} }
+#' \dontshow{ \} }
+#' \dontshow{ \} }
+#' \dontshow{ \} }
+benchmark = function(learners, tasks, resamplings, measures, keep.pred = TRUE,
+  keep.extract = FALSE, models = FALSE, show.info = getMlrOption("show.info")) {
+
   learners = ensureBenchmarkLearners(learners)
   tasks = ensureBenchmarkTasks(tasks)
   resamplings = ensureBenchmarkResamplings(resamplings, tasks)
@@ -55,7 +66,8 @@ benchmark = function(learners, tasks, resamplings, measures, keep.pred = TRUE, m
     task = grid$task,
     learner = grid$learner,
     more.args = list(learners = learners, tasks = tasks, resamplings = resamplings,
-      measures = measures, keep.pred = keep.pred, models = models, show.info = show.info),
+      measures = measures, keep.pred = keep.pred, models = models, show.info = show.info,
+      keep.extract = keep.extract),
     level = plevel
   )
   results.by.task = split(results, unlist(grid$task))
@@ -99,13 +111,20 @@ benchmark = function(learners, tasks, resamplings, measures, keep.pred = TRUE, m
 #' @family benchmark
 NULL
 
-
-benchmarkParallel = function(task, learner, learners, tasks, resamplings, measures, keep.pred = TRUE, models = TRUE, show.info) {
+benchmarkParallel = function(task, learner, learners, tasks, resamplings,
+  measures, keep.pred = TRUE, keep.extract = FALSE, models = FALSE, show.info) {
   setSlaveOptions()
-  if (show.info)
+  if (show.info) {
     messagef("Task: %s, Learner: %s", task, learner)
+  }
   lrn = learners[[learner]]
-  extract.this = getExtractor(lrn)
+  if (isTRUE(keep.extract)) {
+    extract.this = getExtractor(lrn)
+  } else {
+    extract.this = function(model) {
+      NULL
+    }
+  }
   r = resample(lrn, tasks[[task]], resamplings[[task]],
     measures = measures, models = models, extract = extract.this, keep.pred = keep.pred, show.info = show.info)
   # store used learner in result
