@@ -1,4 +1,3 @@
-context("orderedfactors")
 
 test_that("ordered factors", {
   data(BreastCancer, package = "mlbench")
@@ -7,7 +6,8 @@ test_that("ordered factors", {
   df$Id = NULL
   task = makeClassifTask(id = "BreastCancer", data = df, target = "Class")
 
-  expect_equal(getTaskDesc(task)$n.feat, c(numerics = 0L, factors = 4L, ordered = 5L, functionals = 0L))
+  expect_equal(getTaskDesc(task)$n.feat, c(numerics = 0L, factors = 4L,
+    ordered = 5L, functionals = 0L))
   expect_equal(getTaskNFeats(task), 9L)
 
   expect_error(train("classif.lda", task), "has ordered factor")
