@@ -1,4 +1,3 @@
-context("classif_glmboost")
 
 test_that("classif_glmboost", {
   requirePackagesOrSkip("mboost", default.method = "load")
@@ -6,13 +5,16 @@ test_that("classif_glmboost", {
   parset.list1 = list(
     list(family = mboost::Binomial()),
     list(family = mboost::Binomial(), control = mboost::boost_control(nu = 0.03)),
-    list(family = mboost::Binomial(link = "probit"), control = mboost::boost_control(mstop = 600), center = TRUE)
+    list(
+      family = mboost::Binomial(link = "probit"),
+      control = mboost::boost_control(mstop = 10), center = TRUE
+    )
   )
 
   parset.list2 = list(
     list(),
     list(family = "Binomial", nu = 0.03),
-    list(family = "Binomial", Binomial.link = "probit", mstop = 600, center = TRUE)
+    list(family = "Binomial", Binomial.link = "probit", mstop = 10, center = TRUE)
   )
 
   old.predicts.list = list()
@@ -22,16 +24,19 @@ test_that("classif_glmboost", {
     parset = parset.list1[[i]]
     pars = list(binaryclass.formula, data = binaryclass.train)
     pars = c(pars, parset)
-    set.seed(getOption("mlr.debug.seed"))
     m = do.call(mboost::glmboost, pars)
-    set.seed(getOption("mlr.debug.seed"))
     old.predicts.list[[i]] = predict(m, newdata = binaryclass.test, type = "class")
-    set.seed(getOption("mlr.debug.seed"))
     old.probs.list[[i]] = 1 - predict(m, newdata = binaryclass.test, type = "response")[, 1]
   }
 
-  testSimpleParsets("classif.glmboost", binaryclass.df, binaryclass.target, binaryclass.train.inds, old.predicts.list, parset.list2)
-  testProbParsets("classif.glmboost", binaryclass.df, binaryclass.target, binaryclass.train.inds, old.probs.list, parset.list2)
+  testSimpleParsets(
+    "classif.glmboost", binaryclass.df, binaryclass.target,
+    binaryclass.train.inds, old.predicts.list, parset.list2
+  )
+  testProbParsets(
+    "classif.glmboost", binaryclass.df, binaryclass.target,
+    binaryclass.train.inds, old.probs.list, parset.list2
+  )
 })
 
 test_that("classif_glmboost probability predictions with family 'AUC' and 'AdaExp'", {
