@@ -1,4 +1,3 @@
-context("tuneGrid")
 
 test_that("tuneGrid", {
   lrn = makeLearner("classif.ksvm")
@@ -6,7 +5,8 @@ test_that("tuneGrid", {
   c.seq = 2^seq(-2, 2, length.out = reso)
   sigma.seq = 2^seq(-2, 2, length.out = reso)
   sigma.seq.2 = 2^seq(-2, 2, length.out = reso * 2)
-  rin = makeFixedHoldoutInstance(train.inds = seq(1, 150, 2), test.inds = seq(2, 150, 2), size = 150)
+  rin = makeFixedHoldoutInstance(train.inds = seq(1, 150, 2),
+    test.inds = seq(2, 150, 2), size = 150)
   # discretized param set
   ps1 = makeParamSet(
     makeDiscreteParam("C", values = c.seq),
@@ -23,7 +23,8 @@ test_that("tuneGrid", {
     makeDiscreteParam("C", values = c.seq),
     makeDiscreteParam("sigma", values = sigma.seq.2)
   )
-  tr1.2 = tuneParams(lrn, multiclass.task, rin, par.set = ps1.2, control = ctrl, measures = acc)
+  tr1.2 = tuneParams(lrn, multiclass.task, rin, par.set = ps1.2, control = ctrl,
+    measures = acc)
   expect_number(tr1.2$y, lower = 0.8, upper = 1)
   op1.2 = as.data.frame(tr1.2$opt.path)
   op1.2$C = as.numeric(as.character(op1.2$C))
@@ -41,17 +42,20 @@ test_that("tuneGrid", {
   expect_equal(sortByCol(op1, c("C", "sigma")), sortByCol(op2, c("C", "sigma")))
 
   ctrl = makeTuneControlGrid(resolution = c(C = reso, sigma = reso * 2))
-  tr2.2 = tuneParams(lrn, multiclass.task, rin, par.set = ps2, control = ctrl, measures = acc)
+  tr2.2 = tuneParams(lrn, multiclass.task, rin, par.set = ps2, control = ctrl,
+    measures = acc)
   op2.2 = as.data.frame(trafoOptPath(tr2.2$opt.path))
   op1.2$exec.time = op2.2$exec.time = NULL
-  expect_equal(sortByCol(op1.2, c("C", "sigma")), sortByCol(op2.2, c("C", "sigma")))
+  expect_equal(sortByCol(op1.2, c("C", "sigma")),
+    sortByCol(op2.2, c("C", "sigma")))
 })
 
 test_that("tuneGrid works with dependent params", {
   ps = makeParamSet(
     makeDiscreteParam("kernel", values = c("vanilladot", "rbfdot")),
     makeNumericParam("C", lower = 1, upper = 2),
-    makeNumericParam("sigma", lower = 1, upper = 2, requires = quote(kernel == "rbfdot"))
+    makeNumericParam("sigma", lower = 1, upper = 2,
+      requires = quote(kernel == "rbfdot"))
   )
   lrn = makeLearner("classif.ksvm")
   rdesc = makeResampleDesc("Holdout")
@@ -65,10 +69,12 @@ test_that("makeTuneControlGrid throws an error, if budget setting is not appropr
   ps = makeParamSet(
     makeDiscreteParam("kernel", values = c("vanilladot", "rbfdot")),
     makeNumericParam("C", lower = 1, upper = 2),
-    makeNumericParam("sigma", lower = 1, upper = 2, requires = quote(kernel == "rbfdot"))
+    makeNumericParam("sigma", lower = 1, upper = 2,
+      requires = quote(kernel == "rbfdot"))
   )
   lrn = makeLearner("classif.ksvm")
   rdesc = makeResampleDesc("Holdout")
   ctrl = makeTuneControlGrid(resolution = 3L, budget = 50L)
-  expect_error(tuneParams(lrn, multiclass.task, rdesc, par.set = ps, control = ctrl, show.info = FALSE))
+  expect_error(tuneParams(lrn, multiclass.task, rdesc, par.set = ps,
+    control = ctrl, show.info = FALSE))
 })
